#  Django settings for GCIDE web page
#
#  This file is part of GCIDE.
#  Copyright (C) 2008-2010, 2012 Wojciech Polak
#  Copyright (C) 2012 Sergey Poznyakoff
#
#  GCIDE is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3, or (at your option)
#  any later version.
#
#  GCIDE is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCIDE.  If not, see <http://www.gnu.org/licenses/>.

import os
SITE_ROOT = os.path.dirname (os.path.realpath (__file__))

DEBUG = True
TEMPLATE_DEBUG = True

ADMINS = (
    ('Your Name', 'Your e-mail address'),
)
MANAGERS = ADMINS

DATABASE_ENGINE = ''
DATABASE_NAME = ''
DATABASE_USER = ''
DATABASE_PASSWORD = ''
DATABASE_HOST = ''
DATABASE_PORT = ''

SITE_ID = 1
USE_I18N = False

TIME_ZONE = 'Europe/Warsaw'
LANGUAGE_CODE = 'en-us'
LANGUAGE_COOKIE_NAME = 'dicoweb_lang'

SESSION_COOKIE_NAME = 'dicoweb_sid'
SESSION_ENGINE = 'django.contrib.sessions.backends.file'
SESSION_EXPIRE_AT_BROWSER_CLOSE = True

# Caching, see http://docs.djangoproject.com/en/dev/topics/cache/#topics-cache
CACHE_BACKEND = 'memcached://127.0.0.1:11211/'

# Absolute path to the directory that holds media/static files.
MEDIA_ROOT = os.path.join (SITE_ROOT, 'static')

# URL that handles the media served from MEDIA_ROOT.
MEDIA_URL = 'static'

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'SET THIS TO A RANDOM STRING'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.cache.UpdateCacheMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.gzip.GZipMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.cache.FetchFromCacheMiddleware',
)

ROOT_URLCONF = 'gcide.urls'

TEMPLATE_DIRS = (
    os.path.join (SITE_ROOT, 'templates'),
)

INSTALLED_APPS = (
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'gcide',
)

DICT_SERVERS = ('gnu.org.ua',)
DICT_TIMEOUT = 10

# Authentication credentials for servers in DICT_SERVERS.  Missing entry
# means no authentication is needed/required for that server.
# E.g.:
#  AUTH = { '127.0.0.1:12628' : { 'user' : 'gcide', 'password' : 'pass' } }
AUTH = {}

# Set to the most recent GCIDE version
GCIDE_VERSION = 0.51

# GCIDE distribution directory.
GCIDE_FTP = "ftp://gnu.org/gnu/gcide"

# Assoc list of GCIDE distributions.
# Mandatory Keys:
#  archive     Filename of the archive.
#  size        Its size
#  hash        MD5 hash of the archive.
# Optional Keys:
#  ftp         Distribution directory.  If absent GCIDE_FTP is assumed.
#  class       Entry class. Only one value is meaningful so far: 'previous',
#              which means that it is an old release.
GCIDE_DISTRIBUTIONS = ( {'ftp': GCIDE_FTP,
                         'archive': 'gcide-0.51-rc1.tar.gz',
                         'size': '18M',
                         'hash': 'c5e7215fa834eb1675c33a7621dea6ae'},
                        {'ftp': GCIDE_FTP,
                         'archive': 'gcide-0.51-rc1.tar.xz',
                         'size': '14M',
                         'hash': '4bd9b274a893b20b3950cdd5af1c27eb'},
                        {'ftp': GCIDE_FTP,
                         'archive': 'gcide-0.51-rc1.zip',
                         'size': '18M',
                         'hash': '5be7d356878d1d0cd12f6c75478a0004' } )

